@@ -30,7 +30,7 @@ fn main() {
 
   let mut play = Play::new("Animation test".to_string());
   play.initialize();
-  let mut stage = Stage::new(1920, 1080, None);
+  let mut stage = Stage::new("stage".to_string(), 1920, 1080, None);
   stage.set_visible(true);
 
   let mut actor = Actor::new("actor_1".to_string(), 400, 225, None);
